@@ -3,7 +3,7 @@ package Config::Frontend;
 use 5.006;
 use strict;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 sub new {
   my $class=shift;
@@ -67,6 +67,10 @@ sub del {
   }
 }
 
+sub exists {
+return (defined get(@_));
+}
+
 sub variables {
   my $self=shift;
   return $self->{"backend"}->variables();
@@ -137,6 +141,10 @@ var does not exist in the backend.
 
 Deletes a variable from the backend.
 
+=head2 C<exists(var) --E<gt> boolean>
+
+Is true, if C<var> exists. Is false, otherwise.
+
 =head2 C<variables() --E<gt> list of stored variables>
 
 Returns a list all variables stored in the backen.
